import React, { useState } from "react";
import { connect } from "react-redux";
import { bindActionCreators } from "redux";
import PropTypes from "prop-types";
import MessageForAuthorDialog from "./MessageForAuthorDialog";
import { saveMessageForAuthor } from "../actionCreators";
import { toast } from "react-toastify"; //replace with https://material-ui.com/components/snackbars/

const MessageForAuthorContainer = ({ actions, open, handleClose }) => {
  const [messageForAuthor, setMessageForAuthor] = useState("");

  const onMessageForAuthorChanged = (event) => {
    const value = event.target.value;
    setMessageForAuthor(value);
  };

  const saveMessage = () => {
    actions
      .saveMessageForAuthor(messageForAuthor)
      .then((event) => {
        if (event.success) toast.success("Message saved.");
        else toast.error(event.message);
      })
      .catch((error) => {
        toast.error(error);
      });
    setMessageForAuthor("");
    handleClose();
  };

  return (
    <MessageForAuthorDialog
      open={open}
      handleClose={handleClose}
      messageForAuthor={messageForAuthor}
      onMessageForAuthorChanged={onMessageForAuthorChanged}
      saveMessage={saveMessage}
    />
  );
};

MessageForAuthorContainer.propTypes = {
  actions: PropTypes.object.isRequired,
  open: PropTypes.bool.isRequired,
  handleClose: PropTypes.func.isRequired
};

function mapStateToProps() {
  return {};
}

function mapDispatchToProps(dispatch) {
  return {
    actions: bindActionCreators({ saveMessageForAuthor }, dispatch)
  };
}

export default connect(
  mapStateToProps,
  mapDispatchToProps
)(MessageForAuthorContainer);
